@@ -1,11 +1,12 @@
 #include "demodulator.h"
-#include "qsstvglobal.h"
+#include "appglobal.h"
 #include "drm.h"
 #include <math.h>
 #include <float.h>
 #include "nrutil.h"
 #include "utils/supportfunctions.h"
 
+#include <QDebug>
 
 
 demodulator *demodulatorPtr;
@@ -25,7 +26,6 @@ float tempbuf[30000];
 
 demodulator::demodulator()
 {
-  srcDecoder.init();
 }
 
 demodulator::~demodulator()
@@ -88,27 +88,28 @@ bool demodulator::demodulate(float *sigin,int numSamples)
   transmission_frame_buffer_data_valid = 0;
   // fac_valid can be -1,0,1
 
+
   addToLog(QString("block %1 samples %2" ).arg(iterationCounter).arg(numSamples),LOGDRMDEMOD);
-//  if(iterationCounter<40) arrayDump(QString("DEM %1").arg(iterationCounter),sigin,128,true);
-//  arrayDump(QString("bl%1").arg(iterationCounter),sigin,32,true);
-//  logfile->addToAux(QString("block %1").arg(iterationCounter));
-//  arrayDump(QString("rs"),sigin,numSamples*2,true);
-//  if (fac_valid == 0)
-//    {
-//      fac_not_valid_counter--;
-//      if (fac_not_valid_counter <= 0)
-//        {
-//          doSynchronize = true;
-//          fac_not_valid_counter = FACVALIDCNTR;
-//        }
-//    }
-//  else
-//    {
-//      if (fac_valid == 1)
-//        {
-//          fac_not_valid_counter = FACVALIDCNTR;
-//        }
-//    }
+  //  if(iterationCounter<40) arrayDump(QString("DEM %1").arg(iterationCounter),sigin,128,true);
+  //  arrayDump(QString("bl%1").arg(iterationCounter),sigin,32,true);
+  //  logfile->addToAux(QString("block %1").arg(iterationCounter));
+  //  arrayDump(QString("rs"),sigin,numSamples*2,true);
+  //  if (fac_valid == 0)
+  //    {
+  //      fac_not_valid_counter--;
+  //      if (fac_not_valid_counter <= 0)
+  //        {
+  //          doSynchronize = true;
+  //          fac_not_valid_counter = FACVALIDCNTR;
+  //        }
+  //    }
+  //  else
+  //    {
+  //      if (fac_valid == 1)
+  //        {
+  //          fac_not_valid_counter = FACVALIDCNTR;
+  //        }
+  //    }
   if (doSynchronize)
     {
       doSynchronize = false;
@@ -117,11 +118,11 @@ bool demodulator::demodulate(float *sigin,int numSamples)
   if (numberOfSamples> 0)
     {
       ++iterationCounter;
-//      logfile->addToAux(QString("iterationCounter %1").arg(iterationCounter));
-//      arrayDump("sig1",sigin,RXSTRIPE,true);
-//      logfile->addToAux(QString("rsbufwidx %1 offset %2").arg(rsbufwidx).arg(320 * N_symbols_mode_detection/2));
+      //      logfile->addToAux(QString("iterationCounter %1").arg(iterationCounter));
+      //      arrayDump("sig1",sigin,RXSTRIPE,true);
+      //      logfile->addToAux(QString("rsbufwidx %1 offset %2").arg(rsbufwidx).arg(320 * N_symbols_mode_detection/2));
 
-//      arrayDump("sigD",&rs_buffer[320 * N_symbols_mode_detection],16,true);
+      //      arrayDump("sigD",&rs_buffer[320 * N_symbols_mode_detection],16,true);
       for(i=0;i<numberOfSamples;i++)
         {
           rs_buffer[(i + rsbufwidx)*2] = sigin[i*2];
@@ -138,21 +139,30 @@ bool demodulator::demodulate(float *sigin,int numSamples)
         }
 
     }
- if(!timeSync()) return false;
- if(!frequencySync()) return false;
- if(!frameSync()) return false;
- if(channelEstimation())
-   {
-     channel_decoding();
-     srcDecoder.decode();
-   }
- if(doSynchronize)
-   {
-     // see if we have to save the data (for BSR and endOfImage)
-//     srcDecoder.checkSaveImage();
-   }
+  if(!timeSync())
+    {
+      return false;
+    }
+  if(!frequencySync())
+    {
+      return false;
+    }
+  if(!frameSync())
+    {
+      return false;
+    }
+  if(channelEstimation())
+    {
+      channel_decoding();
+      srcDecoder->decode();
+    }
+  if(doSynchronize)
+    {
+      // see if we have to save the data (for BSR and endOfImage)
+      //     srcDecoder.checkSaveImage();
+    }
 
- return true;
+  return true;
 }
 
 bool demodulator::timeSync()
@@ -179,8 +189,8 @@ bool demodulator::timeSync()
       time_offset_integer = (int) floor(time_offset + 0.5);
       if(robustness_mode!=99)
         {
-      addToLog(QString("numSamples %1, robustmode %2,timeoffset %3,smplrateOffsetEst %4,freqOffsetFracInit %5,timeOffsetInteger %6")
-               .arg(numberOfSamples).arg( robustness_mode).arg(time_offset).arg(samplerate_offset_estimation).arg(frequency_offset_fractional_init).arg(time_offset_integer),LOGDRMDEMOD);
+          addToLog(QString("numSamples %1, robustmode %2,timeoffset %3,smplrateOffsetEst %4,freqOffsetFracInit %5,timeOffsetInteger %6")
+                   .arg(numberOfSamples).arg( robustness_mode).arg(time_offset).arg(samplerate_offset_estimation).arg(frequency_offset_fractional_init).arg(time_offset_integer),LOGDRMDEMOD);
         }
 
       if ((fabsf(samplerate_offset_estimation) > 200.0E-5) && (robustness_mode != 99))
@@ -189,12 +199,12 @@ bool demodulator::timeSync()
           N_samples_needed = N_symbols_mode_detection * 320;
           input_samples_buffer_request = N_samples_needed;
           rsbufwidx = 0;
-//          samplerate_offset_estimation=0;
+          //          samplerate_offset_estimation=0;
           return false;
         }
       if (robustness_mode != 99)
         {
-//          logfile->addToAux("timesync found");
+          //          logfile->addToAux("timesync found");
           addToLog(QString("found robustness_mode: %1").arg(robustness_mode),LOGDRMDEMOD);
           timeSyncFlag = true;
           Ts = Ts_list[robustness_mode];
@@ -225,15 +235,15 @@ bool demodulator::timeSync()
         {
           samplerate_offset_estimation = 0.0;
           int shift=320 * N_symbols_mode_detection;
-//          int shift=512;
+          //          int shift=512;
           memmove(rs_buffer,&rs_buffer[shift*2],sizeof(float)*2*(rsbufwidx-shift));
           rsbufwidx -= shift;
-//          arrayDump("sig2",rs_buffer,16,true);
-//          for (i = 0; i < rsbufwidx; i++)	/* pa0mbo was rsbufwidx-1 ? */
-//            {
-//              rs_buffer[i * 2] = rs_buffer[(shift + i) * 2];
-//              rs_buffer[i * 2 + 1] = rs_buffer[(shift + i) * 2 + 1];
-//            }
+          //          arrayDump("sig2",rs_buffer,16,true);
+          //          for (i = 0; i < rsbufwidx; i++)	/* pa0mbo was rsbufwidx-1 ? */
+          //            {
+          //              rs_buffer[i * 2] = rs_buffer[(shift + i) * 2];
+          //              rs_buffer[i * 2 + 1] = rs_buffer[(shift + i) * 2 + 1];
+          //            }
           N_samples_needed = N_symbols_mode_detection * 320 - rsbufwidx;
           if (N_samples_needed > 0)
             {
@@ -286,14 +296,14 @@ bool demodulator::frequencySync()
       for (i = 0; i < N_symbols_frequency_pilot_search; i++)
         {
           delta_time_offset_integer = getofdm(&rs_buffer[2 * t_smp], time_offset_fractional_init,freq_offset_init, delta_time_offset_I_init, Ts, Tu, Zi,
-                                              symbol_temp, 0, 1,1);
+              symbol_temp, 0, 1,1);
           for (j = 0; j < K_modulo; j++)
             {
               symbol_buffer[(i * K_modulo + j) * 2] = symbol_temp[j * 2];
               symbol_buffer[(i * K_modulo + j) * 2 + 1] = symbol_temp[j * 2 + 1];
             }
           t_smp = t_smp + Ts + delta_time_offset_integer;
-         }
+        }
 
       freq_offset_integer = getfoffsint(symbol_buffer, N_symbols_frequency_pilot_search, K_dc,K_modulo, Tu);
       //  prepare for new round
@@ -406,7 +416,7 @@ bool demodulator::frequencySync()
 
 bool demodulator::frameSync()
 {
- int i,j,k;
+  int i,j,k;
   int symbol0;
 
   int symbol_no_to_equalize;
@@ -466,7 +476,7 @@ bool demodulator::frameSync()
 
         {
           delta_time_offset_integer =  getofdm(&rs_buffer[2 * t_smp], time_offset_fractional_init,freq_offset_init, delta_time_offset_I_init, Ts, Tu, Zi,symbol_temp, 0, 1,1);
-//          arrayDump("sm1",symbol_temp,symbols_per_2D_window*2,true);
+          //          arrayDump("sm1",symbol_temp,symbols_per_2D_window*2,true);
           for (j = 0; j < K_modulo; j++)
             {
               symbol_buffer[(i * K_modulo + j) * 2] = symbol_temp[j * 2];
@@ -476,7 +486,7 @@ bool demodulator::frameSync()
           symbufwidx++;
           t_smp += Ts + delta_time_offset_integer;
         }
-//       arrayDump("sm1",symbol_buffer,symbols_per_2D_window*K_modulo*2,true);
+      //       arrayDump("sm1",symbol_buffer,symbols_per_2D_window*K_modulo*2,true);
       // symbol align rs_buffer
       rsbufwidx -= t_smp;
 
@@ -496,9 +506,9 @@ bool demodulator::frameSync()
       for(i=0;i<5;i++)
         for(j=0;j<208;j++)
           for (k=0;k<205;k++)
-        {
-         W_pilots_blk[i][j][k]=0;
-        }
+            {
+              W_pilots_blk[i][j][k]=0;
+            }
 
     }
 
@@ -568,13 +578,13 @@ bool demodulator::channelEstimation()
       spectrum_occupancy = 1;
       mode_and_occupancy_code = mode_and_occupancy_code_table[robustness_mode * 6 + spectrum_occupancy];
     }
+
   if (mode_and_occupancy_code != mode_and_occupancy_code_last)
     {
       K_min = K_min_K_max_list[0][spectrum_occupancy + robustness_mode * 6];
       K_max = K_min_K_max_list[1][spectrum_occupancy + robustness_mode * 6];
       carrier_per_symbol = K_max - K_min + 1;
       (void) getofdmsync(NULL, Ts, Tu, NULL, K_max - K_min + 1, 0, NULL, NULL, 1, 1, 1);	/* initialisation */
-
       //  reformat pilot index stuff into th K_dc/K_modulo block
       //  first call listsinit to get gain_ref_cells_k etc
       //  Jan 5th 2009 changed listsinit() call to an include of all code from listsinit.c
@@ -593,8 +603,7 @@ bool demodulator::channelEstimation()
       for (i = 0; i < cnt_time_ref_cells; i++)
         {
           time_ref_cells_k[i] = time_ref_cells_k_list[robustness_mode][i];
-          time_ref_cells_theta_1024[i] =
-              time_ref_cells_theta_1024_list[robustness_mode][i];
+          time_ref_cells_theta_1024[i] =time_ref_cells_theta_1024_list[robustness_mode][i];
         }
       K_min =
           K_min_K_max_list[0][spectrum_occupancy_estimation +
@@ -690,7 +699,7 @@ bool demodulator::channelEstimation()
 
             }
 
-//          cnt_tr_cells[nnn] = 0;
+          //          cnt_tr_cells[nnn] = 0;
           for (i = 0; i < rndcnt; i++)
             {
               if ((training_cells_k[nnn][i] - K_min) <(carrier_per_symbol * symbols_per_2D_window))
@@ -710,7 +719,6 @@ bool demodulator::channelEstimation()
                   next_pilot_cells_k[nnn][(cnt_next_pilot_cells[nnn])++] = ((training_cells_k[nnn][i]- K_min) % carrier_per_symbol) + K_min;
                 }
             }
-
           //  now sort training cells in subset if necessary
           sortbrkpnt = 0;
           for (i = 1; i < cnt_tr_cells[nnn]; i++)
@@ -741,13 +749,11 @@ bool demodulator::channelEstimation()
                 }
               sortbrkpnt = 0;
             }
-
           //  copy to training_cells_k
           for (i = 0; i < cnt_tr_cells[nnn]; i++)
             {
               training_cells_k[nnn][i] = gain_ref_cells_subset[nnn][i];
             }
-
           gain_ref_cells_per_window = cnt_tr_cells[nnn];
           for (k_index1 = 0; k_index1 < gain_ref_cells_per_window; k_index1++)
             {
@@ -780,7 +786,6 @@ bool demodulator::channelEstimation()
             }
 
           //   now the matrix inversion from numerical recipes
-
           NP = gain_ref_cells_per_window;
           amatrix = matrix(1, NP, 1, NP);
           indxlu = ivector(1, NP);
@@ -909,8 +914,8 @@ bool demodulator::channelEstimation()
           training_cells_relative_index[j] =(gain_ref_cells_k[gain_ref_cells_subset_nn[j]] +(symbols_per_frame -nn) * K_modulo) % (K_modulo * symbols_per_frame);
         }
 
-     cnt_actual_pilots_rel_indx = 0;
-//     logfile->addToAux(QString("block %1").arg(iterationCounter));
+      cnt_actual_pilots_rel_indx = 0;
+      //     logfile->addToAux(QString("block %1").arg(iterationCounter));
       for (j = 0; j < cnt_tr_cells[ntwee]; j++)
         {
           if ((training_cells_relative_index[j] - (symbols_per_2D_window-1) * K_modulo) >= 0)
@@ -986,14 +991,14 @@ bool demodulator::channelEstimation()
       //  get next symbol
       if ((iterationCounter>=0) && (iterationCounter<=180))
         {
-//          arrayDump("b179",&rs_buffer[2 * t_smp],Ts,true);
-//          logfile->addToAux(QString("block %1").arg(iterationCounter));
-//          arrayDump("h179",H,K_max - K_min + 1,true);
+          //          arrayDump("b179",&rs_buffer[2 * t_smp],Ts,true);
+          //          logfile->addToAux(QString("block %1").arg(iterationCounter));
+          //          arrayDump("h179",H,K_max - K_min + 1,true);
         }
       delta_time_offset_integer =getofdmsync(&rs_buffer[2 * t_smp], Ts, Tu, H, K_max - K_min + 1,delta_freq_offset, Zi, symbol_temp, 0, 1,1);
-//      arrayDump("symtmp",symbol_temp,K_modulo,true);
+      //      arrayDump("symtmp",symbol_temp,K_modulo,true);
 
-//      addToLog(QString("delta_time_offset_integer %1").arg(delta_time_offset_integer),LOGDRMDEMOD);
+      //      addToLog(QString("delta_time_offset_integer %1").arg(delta_time_offset_integer),LOGDRMDEMOD);
       for (j = 0; j < K_modulo; j++)
         {
           symbol_buffer[(symbufwidx * K_modulo + j) * 2] = symbol_temp[j * 2];
@@ -1075,7 +1080,7 @@ bool demodulator::channelEstimation()
   SNR_dB = WMERFAC;
 
   addToLog(QString("SNR-FAC =%1").arg(SNR_dB),LOGDRMDEMOD);
-//  N_samples_needed = (symbols_per_frame + 1) * Ts - rsbufwidx;
+  //  N_samples_needed = (symbols_per_frame + 1) * Ts - rsbufwidx;
 
   if (SNR_dB < SNR_MIN_DB)
     {
