@@ -1,7 +1,7 @@
 #include "fixform.h"
 #include "ui_fixform.h"
 #include "drmstatusframe.h"
-#include "qsstvglobal.h"
+#include "appglobal.h"
 #include "drmrx/drm.h"
 #include "configparams.h"
 
