@@ -1,11 +1,11 @@
 #include "sourcedecoder.h"
 #include "drm.h"
-#include "qsstvglobal.h"
+#include "appglobal.h"
 #include "drmproto.h"
 #include <math.h>
 #include <float.h>
 #include "configparams.h"
-#include "dispatcher.h"
+#include "dispatch/dispatcher.h"
 #include <QApplication>
 #include <QFileInfo>
 #include "utils/reedsolomoncoder.h"
@@ -13,24 +13,24 @@
 #include "drmrx/demodulator.h"
 #include "utils/ftp.h"
 #include "configparams.h"
-#include "utils/qjp2io.h"
-#include "utils/hybridcrypt.h"
+
 #include "logbook/logbook.h"
 #include "drmrx/drmstatusframe.h"
 
 sourceDecoder::sourceDecoder(QObject *parent) : QObject(parent)
 {
-
+transportBlockPtrList.clear();
 }
 
 void sourceDecoder::init()
 {
   lastTransportBlockPtr=NULL;
-  transportBlockPtrList.clear();
+
   bodyTotalSegments=0;
   checkIt=false;
   erasureList.clear();
   lastContinuityIndex=-1;
+  alreadyDisplayed=false;
 }
 
 
@@ -83,8 +83,8 @@ bool sourceDecoder::decode()
     case MOTDATA:  addToLog("Datasegment",LOGDRMSRC);   addDataSegment(); break;
     case MOTHEAD:  addToLog("Headersegment",LOGDRMSRC); addHeaderSegment(); break;
     default:
-    return false;
-    break;
+      return false;
+      break;
     }
   return true;
 }
@@ -268,6 +268,8 @@ void dataPacket::log()
 
 bool sourceDecoder::addHeaderSegment()
 {
+  loadRXImageEvent *stce;
+  displayMBoxEvent *stmb;
   transportBlock *tbPtr;
   addToLog(QString("Header segsize: %1").arg(currentDataPacket.segmentSize),LOGDRMSRC);
   tbPtr=getTransporPtr(currentDataPacket.transportID,true);
@@ -275,6 +277,18 @@ bool sourceDecoder::addHeaderSegment()
   else
     {
       msc_valid=ALREADYRECEIVED;
+      if(!alreadyDisplayed)
+        {
+          alreadyDisplayed=true;
+          // redisplay
+          stce= new loadRXImageEvent(QString("%1").arg(tbPtr->newFileName));
+          QApplication::postEvent( dispatcherPtr, stce );  // Qt will delete it when done
+          stmb= new displayMBoxEvent("DRM Receive",QString("File %1 already received").arg(tbPtr->newFileName));
+          QApplication::postEvent( dispatcherPtr, stmb );
+        }
+
+
+
       return true;
     }
 
@@ -309,15 +323,15 @@ bool sourceDecoder::addHeaderSegment()
         {
         case 0:
           currentDataPacket.advance(1);
-        break;
+          break;
         case 1:
           loadParams(tbPtr,paramID,1);
           currentDataPacket.advance(2);
-        break;
+          break;
         case 2:
           loadParams(tbPtr,paramID,4);
           currentDataPacket.advance(5);
-        break;
+          break;
         case 3:
           extBit=dataPtr[0]&0x80;
           if(extBit)
@@ -332,7 +346,7 @@ bool sourceDecoder::addHeaderSegment()
             }
           loadParams(tbPtr,paramID,dataFieldLength);
           currentDataPacket.advance(dataFieldLength);
-        break;
+          break;
         }
     }
   return true;
@@ -341,21 +355,24 @@ bool sourceDecoder::addHeaderSegment()
 
 void sourceDecoder::loadParams(transportBlock *tbPtr,unsigned char paramID,int len)
 {
+//  QByteArray testBA;
+//  char *data;
+//  unsigned int ct;
   rxDRMStatusEvent *stce;
   QString tmp,t;
   switch(paramID)
     {
     case 5: // expiration
-    break;
+      break;
     case 6:
-    break;
+      break;
     case 12:
-      tbPtr->fileName=QString(currentDataPacket.ba.data()+1).left(len-1);
+      tbPtr->fileName=QString::fromLatin1(currentDataPacket.ba.data()+1).left(len-1);
       stce= new rxDRMStatusEvent(QString("%1").arg(tbPtr->fileName));
       QApplication::postEvent( dispatcherPtr, stce );  // Qt will delete it when done
-    break;
+      break;
     default:
-    break;
+      break;
     }
 }
 
@@ -369,7 +386,7 @@ void sourceDecoder::addDataSegment()
   if(callsignValid) tbPtr->callsign=drmCallsign;
   addToLog(QString("Data segsize: %1 segment# %2").arg(currentDataPacket.segmentSize).arg(currentDataPacket.segmentNumber),LOGDRMSRC);
 
-  bodyTotalSegments=tbPtr->totalSegments;
+
   if(!tbPtr->alreadyReceived) msc_valid=VALID;
   else
     {
@@ -385,10 +402,6 @@ void sourceDecoder::addDataSegment()
     {
       tbPtr->defaultSegmentSize=currentDataPacket.segmentSize;
     }
-  if(tbPtr->defaultSegmentSize==0)
-    {
-      //      qDebug() << "def seg size not set";
-    }
   for(i=tbPtr->dataSegmentPtrList.count();i<=currentDataPacket.segmentNumber;i++)
     {
       tbPtr->dataSegmentPtrList.append(new dataSegment(tbPtr->defaultSegmentSize));
@@ -407,9 +420,8 @@ void sourceDecoder::addDataSegment()
       msc_valid=ALREADYRECEIVED;
       checkIt=false;
     }
-
-
   if(tbPtr->totalSegments<currentDataPacket.segmentNumber+1) tbPtr->totalSegments=currentDataPacket.segmentNumber+1;
+  bodyTotalSegments=tbPtr->totalSegments;
   rxSegments=tbPtr->segmentsReceived;
   //  bytesReceived=rxSegments*tbPtr->defaultSegmentSize;
 
@@ -441,7 +453,6 @@ void sourceDecoder::writeData(transportBlock *tbPtr)
           ba.append(tbPtr->dataSegmentPtrList.at(i)->data);
         }
       length+=tbPtr->dataSegmentPtrList.at(i)->data.size();
-      //      qDebug()<< "block" << i<< "len" << tbPtr->dataSegmentPtrList.at(i)->data.size() ;
     }
   tbPtr->segmentsReceived=0;
   drmBlockList.clear();
@@ -465,7 +476,7 @@ void sourceDecoder::saveImage(transportBlock *tbPtr)
   int i;
   eftpError ftpResult;
   QByteArray hybridBa;
-  hybridCrypt hc;
+
   QImage test;
   displayTextEvent *stce;
   displayMBoxEvent *stmb=0;
@@ -475,17 +486,21 @@ void sourceDecoder::saveImage(transportBlock *tbPtr)
   bool textMode=false;
   QString downloadF;
   bool   saveOK=false;
-
-  if(tbPtr->alreadyReceived) return ;
+  alreadyDisplayed=true;
+  if(tbPtr->alreadyReceived)
+    {
+      return ;
+    }
   if(tbPtr->fileName.isEmpty()) return ;
   lastAvgSNR=avgSNR;
   isHybrid=false;
-  if(tbPtr->fileName.left(3)=="de_")
+  if((tbPtr->fileName.left(3)==".de") || (tbPtr->fileName.left(3)=="de_"))
     {
       isHybrid=true;
-      if(enableHybridRx)
+      if((enableHybridRx) && (soundRoutingInput!=soundBase::SNDINFROMFILE))
         {
-          downloadF=rxImagesPath+"/"+tbPtr->fileName;
+          addToLog(QString("Hybrid filename %1").arg(tbPtr->fileName),LOGALL);
+          downloadF=rxDRMImagesPath+"/"+tbPtr->fileName;
           for(i=0;i<tbPtr->dataSegmentPtrList.count();i++)
             {
               hybridBa+=tbPtr->dataSegmentPtrList.at(i)->data;
@@ -493,25 +508,28 @@ void sourceDecoder::saveImage(transportBlock *tbPtr)
           if(hc.deCrypt(&hybridBa))
             {
 
-
               ftpIntf.setupConnection(hc.host(),hc.port(),hc.user(),hc.passwd(),hc.dir()+"/"+hybridFtpHybridFilesDirectory);
-              ftpResult=ftpIntf.downloadFile(tbPtr->fileName,downloadF);
+              ftpResult=ftpIntf.downloadFile(tbPtr->fileName.toLatin1(),downloadF);
               switch(ftpResult)
                 {
                 case FTPOK:
-                break;
+                  break;
                 case FTPERROR:
                   stmb= new displayMBoxEvent("FTP Error",QString("Host: %1: %2").arg(ftpRemoteHost).arg(ftpIntf.getLastError()));
-                break;
+                  errorOut() << "ftp error" << ftpRemoteHost << ftpIntf.getLastError();
+                  break;
                 case FTPNAMEERROR:
                   stmb= new displayMBoxEvent("FTP Error",QString("Host: %1, Error in filename").arg(ftpRemoteHost));
-                break;
+                  errorOut() << "ftp filename error" << ftpRemoteHost << ftpIntf.getLastError();
+                  break;
                 case FTPCANCELED:
                   stmb= new displayMBoxEvent("FTP Error",QString("Connection to %1 Canceled").arg(ftpRemoteHost));
-                break;
+                  errorOut() << "ftp connection error" << ftpRemoteHost << ftpIntf.getLastError();
+                  break;
                 case FTPTIMEOUT:
                   stmb= new displayMBoxEvent("FTP Error",QString("Connection to %1 timed out").arg(ftpRemoteHost));
-                break;
+                  errorOut() << "ftp connection timeout error" << ftpRemoteHost << ftpIntf.getLastError();
+                  break;
                 }
               if(ftpResult!=FTPOK)
                 {
@@ -541,22 +559,18 @@ void sourceDecoder::saveImage(transportBlock *tbPtr)
   //  test=readJP2Image(tbPtr->newFileName);
   if(!test.load(tbPtr->newFileName))
     {
-      test=readJP2Image(tbPtr->newFileName);
-      if(test.isNull())
-        {
-          // maybe text
-          QFileInfo finfo(tbPtr->newFileName);
-          if((finfo.suffix()=="txt") || (finfo.suffix()=="chat") )
-            {
-              QFile fi(tbPtr->newFileName);
-              if(!fi.open(QIODevice::ReadOnly)) return;
-              t=fi.readAll();
-              stce= new displayTextEvent(t);
-              QApplication::postEvent( dispatcherPtr, stce );  // Qt will delete it when done
-              textMode=true;
-            }
-        }
 
+      // maybe text
+      QFileInfo finfo(tbPtr->newFileName);
+      if((finfo.suffix()=="txt") || (finfo.suffix()=="chat") )
+        {
+          QFile fi(tbPtr->newFileName);
+          if(!fi.open(QIODevice::ReadOnly)) return;
+          t=fi.readAll();
+          stce= new displayTextEvent(t);
+          QApplication::postEvent( dispatcherPtr, stce );  // Qt will delete it when done
+          textMode=true;
+        }
       saveOK=true;
     }
   else
@@ -566,11 +580,13 @@ void sourceDecoder::saveImage(transportBlock *tbPtr)
   if(saveOK)
     {
       QFileInfo tfi(tbPtr->newFileName);
+
       QString modestr(tfi.fileName());
       modestr+=" ";
       if(isHybrid) modestr+="Hybrid ";
       modestr+=compactModeToString(tbPtr->modeCode);
-      logBookPtr->logQSO(tbPtr->callsign,modestr);
+      logBookPtr->logQSO(tbPtr->callsign,"DSSTV",modestr);
+
     }
   tbPtr->setAlreadyReceived(true);
   if(!textMode)
@@ -593,7 +609,7 @@ bool sourceDecoder::checkSaveImage(QByteArray ba,transportBlock *tbPtr)
   reedSolomonCoder rsd;
   QString fileName;
   QString extension;
-  fileName=rxImagesPath+"/"+tbPtr->fileName;
+  fileName=rxDRMImagesPath+"/"+tbPtr->fileName;
   tbPtr->newFileName=fileName;
   QByteArray baFile;
   QByteArray *baFilePtr;
@@ -667,15 +683,8 @@ bool sourceDecoder::storeBSR(transportBlock *tb, bool compat)
       if(!tb->dataSegmentPtrList.at(i)->hasData())
         {
           erasureList.append(i);
-          //         ba.append(QByteArray(tb->defaultSegmentSize,0x00));
         }
-      else
-        {
-          //          ba.append(tb->dataSegmentPtrList.at(i)->data);
-        }
-      //      length+=tb->dataSegmentPtrList.at(i)->data.size();
-      //      qDebug()<< "block" << i<< "len" << tbPtr->dataSegmentPtrList.at(i)->data.size() ;
-    }
+     }
   tb->baBSR.clear();
   if(erasureList.count()<3) return false; //erasurelist has already totalSegments and defaultSegmentSize
   tb->baBSR.append(QString::number(tb->transportID).toLatin1().data());
@@ -745,6 +754,8 @@ transportBlock *sourceDecoder::getTransporPtr(unsigned short tId,bool create)
   else if (create)
     {
       callsignValid=false;
+      bodyTotalSegments=0;
+      drmBlockList.clear();
       stce= new rxDRMStatusEvent("");
       QApplication::postEvent( dispatcherPtr, stce );  // Qt will delete it when done
       if(transportBlockPtrList.count()>=MAXTRANSPORTLISTS)
@@ -757,7 +768,6 @@ transportBlock *sourceDecoder::getTransporPtr(unsigned short tId,bool create)
           if(transportBlockPtrList.at(i)->fileName=="bsr.bin")
             {
               transportBlockPtrList.takeAt(i);
-              //              qDebug()<< "deleting bsr.bin";
             }
           else i++;
         }
