@@ -6,6 +6,9 @@
 #include <QPushButton>
 #include <QLabel>
 
+class configDialog;
+class spectrumWidget;
+
 namespace Ui {
   class MainWindow;
   }
@@ -18,42 +21,54 @@ public:
   explicit mainWindow(QWidget *parent = 0);
   ~mainWindow();
   void init();
+  void startRunning();
   void setNewFont();
   void setPTT(bool p);
-  void setBSRPushButton(bool b);
-  void startReceiving();
+  void setSSTVDRMPushButton(bool inDRM);
+  spectrumWidget *spectrumFramePtr;
 
 private slots:
   void slotConfigure();
   void slotExit();
   void slotResetLog();
   void slotLogSettings();
-  void slotCalibrate();
   void slotAboutQt();
   void slotAboutQSSTV();
   void slotDocumentation();
+  void slotCalibrate();
+  void slotModeChange(int);
   void slotSendID();
   void slotSendBSR();
   void slotSendWfText();
+  void slotSetFrequency(int freqIndex);
+
+
 #ifndef QT_NO_DEBUG
   void slotShowDataScope();
-  void slotShowSyncScope();
+  void slotShowSyncScopeNarrow();
+  void slotShowSyncScopeWide();
   void slotScopeOffset();
+  void slotDumpSamplesPerLine();
 
 #endif
+
 private:
   Ui::MainWindow *ui;
   void closeEvent ( QCloseEvent *e );
   void readSettings();
   void writeSettings();
+  void restartSound(bool inStartUp);
   QComboBox *transmissionModeComboBox;
   QPushButton *wfTextPushButton;
   QPushButton *fixPushButton;
   QPushButton *bsrPushButton;
   QPushButton *idPushButton;
+  QComboBox *freqComboBox;
   QLabel pttText;
   QLabel *pttIcon;
-
+  QLabel *freqDisplay;
+  void timerEvent(QTimerEvent *);
+  QStringList modModeList;
 };
 
 #endif // MAINWINDOW_H
